==> jc-1.4.0.tar.gz: javax/xml/xpath/XPathFactoryConfigurationException.h <==
// public class javax.xml.xpath.XPathFactoryConfigurationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class bf48a3b3cd7f380d javax_xml_xpath_XPathException
// @dep_class b9b9ffeba9e051a6 javax_xml_xpath_XPathFactoryConfigurationException

// header file dependencies
// @dep_header javax_xml_xpath_XPathException

#include "javax/xml/xpath/XPathException.h"

#ifndef _JC_javax_xml_xpath_XPathFactoryConfigurationException_H_
#define _JC_javax_xml_xpath_XPathFactoryConfigurationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_refs	_jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_refs;
typedef struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_nonrefs	_jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_nonrefs;
typedef struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$refs	_jc_javax_xml_xpath_XPathFactoryConfigurationException$refs;
typedef struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$nonrefs	_jc_javax_xml_xpath_XPathFactoryConfigurationException$nonrefs;
typedef struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$object	_jc_javax_xml_xpath_XPathFactoryConfigurationException$object;

typedef const struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$vmethods	_jc_javax_xml_xpath_XPathFactoryConfigurationException$vmethods;
typedef const struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$vtable	_jc_javax_xml_xpath_XPathFactoryConfigurationException$vtable;
typedef const struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$vtype	_jc_javax_xml_xpath_XPathFactoryConfigurationException$vtype;

// Constructors
extern void _jc_javax_xml_xpath_XPathFactoryConfigurationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_xml_xpath_XPathFactoryConfigurationException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods structure
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$vmethods {
};

// Vtable
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_xml_xpath_XPathException$vmethods	javax_xml_xpath_XPathException;
	_jc_javax_xml_xpath_XPathFactoryConfigurationException$vmethods	javax_xml_xpath_XPathFactoryConfigurationException;
};

// Vtype
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$vtype {
	_jc_type			type;
	_jc_javax_xml_xpath_XPathFactoryConfigurationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$refs {
    _jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_refs	javax_xml_xpath_XPathFactoryConfigurationException;
    _jc_javax_xml_xpath_XPathException$sub_refs	javax_xml_xpath_XPathException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_xml_xpath_XPathException$sub_nonrefs	javax_xml_xpath_XPathException;
    _jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_nonrefs	javax_xml_xpath_XPathFactoryConfigurationException;
};

// Object instance structure
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$object {
	_jc_javax_xml_xpath_XPathFactoryConfigurationException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_xpath_XPathFactoryConfigurationException$vtype	*vtype;
	_jc_javax_xml_xpath_XPathFactoryConfigurationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_xpath_XPathFactoryConfigurationException$vtype _jc_javax_xml_xpath_XPathFactoryConfigurationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_xpath_XPathFactoryConfigurationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_xpath_XPathFactoryConfigurationException$class_object;

#endif	/* _JC_javax_xml_xpath_XPathFactoryConfigurationException_H_ */

==> jc-1.4.6.tar.gz: javax/xml/xpath/XPathFactoryConfigurationException.h <==
// public class javax.xml.xpath.XPathFactoryConfigurationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class bf48a3b3cd7f380d javax_xml_xpath_XPathException
// @dep_class b9b9ffeba9e051a6 javax_xml_xpath_XPathFactoryConfigurationException

// header file dependencies
// @dep_header javax_xml_xpath_XPathException

#include "javax/xml/xpath/XPathException.h"

#ifndef _JC_javax_xml_xpath_XPathFactoryConfigurationException_H_
#define _JC_javax_xml_xpath_XPathFactoryConfigurationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_refs	_jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_refs;
typedef struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_nonrefs	_jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_nonrefs;
typedef struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$refs	_jc_javax_xml_xpath_XPathFactoryConfigurationException$refs;
typedef struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$nonrefs	_jc_javax_xml_xpath_XPathFactoryConfigurationException$nonrefs;
typedef struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$object	_jc_javax_xml_xpath_XPathFactoryConfigurationException$object;

typedef const struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$vmethods	_jc_javax_xml_xpath_XPathFactoryConfigurationException$vmethods;
typedef const struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$vtable	_jc_javax_xml_xpath_XPathFactoryConfigurationException$vtable;
typedef const struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$vtype	_jc_javax_xml_xpath_XPathFactoryConfigurationException$vtype;

// Constructors
extern void _jc_javax_xml_xpath_XPathFactoryConfigurationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_xml_xpath_XPathFactoryConfigurationException$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$vmethods {
};

// Vtable
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_xml_xpath_XPathException$vmethods	javax_xml_xpath_XPathException;
	_jc_javax_xml_xpath_XPathFactoryConfigurationException$vmethods	javax_xml_xpath_XPathFactoryConfigurationException;
};

// Vtype
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$vtype {
	_jc_type			type;
	_jc_javax_xml_xpath_XPathFactoryConfigurationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$refs {
    _jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_refs	javax_xml_xpath_XPathFactoryConfigurationException;
    _jc_javax_xml_xpath_XPathException$sub_refs	javax_xml_xpath_XPathException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_xml_xpath_XPathException$sub_nonrefs	javax_xml_xpath_XPathException;
    _jc_javax_xml_xpath_XPathFactoryConfigurationException$sub_nonrefs	javax_xml_xpath_XPathFactoryConfigurationException;
};

// Object instance structure
struct _jc_javax_xml_xpath_XPathFactoryConfigurationException$object {
	_jc_javax_xml_xpath_XPathFactoryConfigurationException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_xml_xpath_XPathFactoryConfigurationException$vtype	*vtype;
	_jc_javax_xml_xpath_XPathFactoryConfigurationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_xml_xpath_XPathFactoryConfigurationException$vtype _jc_javax_xml_xpath_XPathFactoryConfigurationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_xml_xpath_XPathFactoryConfigurationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_xml_xpath_XPathFactoryConfigurationException$class_object;

#endif	/* _JC_javax_xml_xpath_XPathFactoryConfigurationException_H_ */
